@@ -129,39 +129,59 @@ class GPGFile:
     def read(self, length = -1):
         try:
             res = self.gpg_output.read(length)
-        except:
-            self.print_log()
-            raise
+        except Exception, e:
+            self.gpg_failed()
         return res
 
     def write(self, buf):
         try:
             res = self.gpg_input.write(buf)
         except:
-            self.print_log()
-            raise
+            self.gpg_failed()
         return res
 
-    def print_log(self):
+    def gpg_failed(self):
+        self.print_log(0)
+        log.FatalError("GPG Failed, see log above", log.ErrorCode.gpg_failed)
+
+    def print_log(self, level):
+        log.Log("===== Begin GnuPG log =====", level)
         self.logger_fp.seek(0)
         for line in self.logger_fp:
-            print line,
+            log.Log(line.strip(), level)
+        log.Log("===== End GnuPG log =====", level)
 
     def close(self):
         if self.encrypt:
-            self.gpg_input.close()
+            try:
+                self.gpg_input.close()
+            except:
+                self.gpg_failed()
             if self.status_fp:
                 self.set_signature()
-            self.gpg_process.wait()
+            try:
+                self.gpg_process.wait()
+            except:
+                self.gpg_failed()
         else:
-            while self.gpg_output.read(blocksize):
-                pass # discard remaining output to avoid GPG error
-            self.gpg_output.close()
+            res = 1
+            while res:
+                # discard remaining output to avoid GPG error
+                try:
+                    res = self.gpg_output.read(blocksize)
+                except:
+                    self.gpg_failed()
+            try:
+                self.gpg_output.close()
+            except:
+                self.gpg_failed()
             if self.status_fp:
                 self.set_signature()
-            self.gpg_process.wait()
-        if log.getverbosity() >= 5:
-            self.print_log()
+            try:
+                self.gpg_process.wait()
+            except:
+                self.gpg_failed()
+        self.print_log(5)
         self.logger_fp.close()
         self.closed = 1
 
